@@ -39,7 +39,7 @@ public:
     void setState(Session::State s);
     void startSsl();
 
-    QSsl::SslProtocol negotiatedEncryption() const;
+    Q_REQUIRED_RESULT QSsl::SslProtocol negotiatedEncryption() const;
 
 public Q_SLOTS:
     void handleSslError(const KSslErrorUiData &data);
@@ -84,6 +84,7 @@ private:
     int m_size = 0;
     bool m_allowsTls = false;
     bool m_starttlsSent = false;
+    bool m_allowsDns = false;
     QStringList m_authModes;
     QString m_customHostname;
 };
